@@ -26,13 +26,13 @@
  *
  * Contributor(s): ______________________________________.
  *
- * $Revision: 20385 $
+ * $Revision: 21788 $
  * $Author: rjongbloed $
- * $Date: 2008-06-04 10:40:38 +0000 (Wed, 04 Jun 2008) $
+ * $Date: 2008-12-12 05:42:13 +0000 (Fri, 12 Dec 2008) $
  */
 
-#ifndef _PTIMEINTERVAL
-#define _PTIMEINTERVAL
+#ifndef PTLIB_TIMEINTERVAL_H
+#define PTLIB_TIMEINTERVAL_H
 
 #ifdef P_USE_PRAGMA
 #pragma interface
@@ -383,7 +383,7 @@ class PTimeInterval : public PObject
 #endif
 };
 
-#endif
+#endif // PTLIB_TIMEINTERVAL_H
 
 
 // End Of File ///////////////////////////////////////////////////////////////
