@@ -23,9 +23,9 @@
  *
  * Contributor(s): Federico Pinna and Reitek S.p.A. (SASL authentication)
  *
- * $Revision: 20385 $
+ * $Revision: 21788 $
  * $Author: rjongbloed $
- * $Date: 2008-06-04 12:40:38 +0200 (mer 04 jun 2008) $
+ * $Date: 2008-12-12 05:42:13 +0000 (Fri, 12 Dec 2008) $
  */
 
 #ifdef __GNUC__
@@ -208,7 +208,7 @@ PBoolean PSMTPClient::BeginMessage(const PString & from,
   toNames.RemoveAll();
   toNames.AppendString(to);
   eightBitMIME = useEightBitMIME;
-  return _BeginMessage();
+  return InternalBeginMessage();
 }
 
 
@@ -219,11 +219,11 @@ PBoolean PSMTPClient::BeginMessage(const PString & from,
   fromAddress = from;
   toNames = toList;
   eightBitMIME = useEightBitMIME;
-  return _BeginMessage();
+  return InternalBeginMessage();
 }
 
 
-PBoolean PSMTPClient::_BeginMessage()
+PBoolean PSMTPClient::InternalBeginMessage()
 {
   PString localHost;
   PString peerHost;
