@@ -23,9 +23,9 @@
  *
  * Contributor(s): ______________________________________.
  *
- * $Revision: 21525 $
- * $Author: csoutheren $
- * $Date: 2008-11-14 11:01:53 +0000 (Fri, 14 Nov 2008) $
+ * $Revision: 22944 $
+ * $Author: rjongbloed $
+ * $Date: 2009-06-22 01:46:40 +0000 (Mon, 22 Jun 2009) $
  */
 
 #ifdef __GNUC__
@@ -155,8 +155,7 @@ PURL::PURL(const PString & str, const char * defaultScheme)
 
 
 PURL::PURL(const PFilePath & filePath)
-  : //scheme(SchemeTable[FILE_SCHEME].name),
-    scheme(FILE_SCHEME),
+  : scheme(FILE_SCHEME),
     port(0),
     portSupplied (PFalse),
     relativePath(PFalse)
@@ -236,31 +235,31 @@ PString PURL::TranslateString(const PString & str, TranslationType type)
 {
   PString xlat = str;
 
-  PString safeChars = "abcdefghijklmnopqrstuvwxyz"
-                      "ABCDEFGHIJKLMNOPQRSTUVWXYZ"
-                      "0123456789$-_.!*'(),";
+  /* Characters sets are from RFC2396.
+     The EBNF defines lowalpha, upalpha, digit and mark which are always
+     allowed. The reserved list consisting of ";/?:@&=+$," may or may not be
+     allowed depending on the syntatic element being encoded.
+   */
+  PString safeChars = "abcdefghijklmnopqrstuvwxyz"  // lowalpha
+                      "ABCDEFGHIJKLMNOPQRSTUVWXYZ"  // upalpha
+                      "0123456789"                  // digit
+                      "-_.!~*'()";                  // mark
   switch (type) {
     case LoginTranslation :
-      safeChars += "+;?&=";
+      safeChars += ";&=+$,";  // Section 3.2.2
       break;
 
     case PathTranslation :
-      safeChars += "+:@&=";
+      safeChars += ":@&=+$,";   // Section 3.3
       break;
 
     case QueryTranslation :
-      safeChars += ":@";
+      break;    // Section 3.4, no reserved characters may be used
   }
   PINDEX pos = (PINDEX)-1;
   while ((pos = xlat.FindSpan(safeChars, pos+1)) != P_MAX_INDEX)
     xlat.Splice(psprintf("%%%02X", (BYTE)xlat[pos]), pos, 1);
 
-  if (type == QueryTranslation) {
-    PINDEX space = (PINDEX)-1;
-    while ((space = xlat.Find(' ', space+1)) != P_MAX_INDEX)
-      xlat[space] = '+';
-  }
-
   return xlat;
 }
 
@@ -272,6 +271,8 @@ PString PURL::UntranslateString(const PString & str, TranslationType type)
 
   PINDEX pos;
   if (type == PURL::QueryTranslation) {
+    /* Even though RFC2396 never mentions this, and RFC1630 is quite vague
+       about it, a lot of things do it so we have to do it too */
     pos = (PINDEX)-1;
     while ((pos = xlat.Find('+', pos+1)) != P_MAX_INDEX)
       xlat[pos] = ' ';
@@ -593,27 +594,26 @@ PBoolean PURL::LegacyParse(const PString & _url, const PURLLegacyScheme * scheme
 
 PFilePath PURL::AsFilePath() const
 {
-  //if (scheme != SchemeTable[FILE_SCHEME].name)
-  //  return PString::Empty();
-  if (scheme != FILE_SCHEME)
+  /* While it is never explicitly stated anywhere in RFC1798, there is an
+     implication RFC 1808 that the path is absolute unless the relative
+     path rules of that RFC apply. We follow that logic. */
+
+  if (path.IsEmpty() || scheme != FILE_SCHEME || (!hostname.IsEmpty() && hostname != "localhost"))
     return PString::Empty();
 
   PStringStream str;
 
-  if (relativePath) {
-    for (PINDEX i = 0; i < path.GetSize(); i++) {
-      if (i > 0)
-        str << PDIR_SEPARATOR;
-      str << path[i];
-    }
-  }
+  if (path[0].GetLength() == 2 && path[0][1] == '|')
+    str << path[0][0] << ':' << PDIR_SEPARATOR; // Special case for Windows paths with drive letter
   else {
-    if (hostname != "localhost")
-      str << PDIR_SEPARATOR << hostname;
-    for (PINDEX i = 0; i < path.GetSize(); i++)
-      str << PDIR_SEPARATOR << path[i];
+    if (!relativePath)
+      str << PDIR_SEPARATOR;
+    str << path[0];
   }
 
+  for (PINDEX i = 1; i < path.GetSize(); i++)
+    str << PDIR_SEPARATOR << path[i];
+
   return str;
 }
 
@@ -626,9 +626,6 @@ PString PURL::AsString(UrlFormat fmt) const
   if (scheme.IsEmpty())
     return PString::Empty();
 
-  //const schemeStruct * schemeInfo = GetSchemeInfo(scheme);
-  //if (schemeInfo == NULL)
-  //  schemeInfo = &SchemeTable[PARRAYSIZE(SchemeTable)-1];
   const PURLScheme * schemeInfo = PFactory<PURLScheme>::CreateInstance(scheme);
   if (schemeInfo == NULL)
     schemeInfo = PFactory<PURLScheme>::CreateInstance(DEFAULT_SCHEME);
@@ -883,8 +880,6 @@ PBoolean PURL::OpenBrowser(const PString & url)
 
 void PURL::Recalculate()
 {
-  //if (scheme.IsEmpty())
-  //  scheme = SchemeTable[DEFAULT_SCHEME].name;
   if (scheme.IsEmpty())
     scheme = DEFAULT_SCHEME;
 
