@@ -26,9 +26,9 @@
  *
  * Contributor(s): ______________________________________.
  *
- * $Revision: 21995 $
+ * $Revision: 23018 $
  * $Author: rjongbloed $
- * $Date: 2009-02-04 23:59:32 +0000 (Wed, 04 Feb 2009) $
+ * $Date: 2009-07-01 00:13:04 +0000 (Wed, 01 Jul 2009) $
  */
 
 #include <ptlib.h>
@@ -67,12 +67,8 @@ void CALLBACK CompletionRoutine(DWORD dwError,
 #endif // P_QOS
 
 
-#if P_HAS_IPV6
-#define HAS_GETADDRINFO 1
-#endif
-
-#if (defined(_WIN32) && defined (_MSC_VER))
-#define HAS_GETADDRINFO 1
+#if P_HAS_IPV6 || defined(AI_NUMERICHOST)
+  #define HAS_GETADDRINFO 1
 #endif
 
 
@@ -283,7 +279,7 @@ class PHostByName : PHostByName_private
   friend void PIPSocket::ClearNameCache();
 };
 
-PMutex creationMutex;
+static PMutex creationMutex;
 static PHostByName & pHostByName()
 {
   PWaitAndSignal m(creationMutex);
@@ -535,7 +531,8 @@ PIPCacheData * PHostByName::GetHost(const PString & name)
     struct addrinfo hints = { AI_CANONNAME, defaultIpAddressFamily };
     localErrNo = getaddrinfo((const char *)name, NULL , &hints, &res);
     host = new PIPCacheData(localErrNo != NETDB_SUCCESS ? NULL : res, name);
-    freeaddrinfo(res);
+    if (res != NULL)
+      freeaddrinfo(res);
 
 #else // HAS_GETADDRINFO
 
@@ -1925,7 +1922,8 @@ PBoolean PIPSocket::Address::FromString(const PString & ipAndInterface)
         struct sockaddr_in * addr_in = (struct sockaddr_in *)res->ai_addr;
         v.four = addr_in->sin_addr;
       }
-      freeaddrinfo(res);
+      if (res != NULL)
+        freeaddrinfo(res);
       return IsValid();
     }
 
