@@ -26,9 +26,9 @@
  *
  * Contributor(s): ______________________________________.
  *
- * $Revision: 20418 $
+ * $Revision: 22082 $
  * $Author: rjongbloed $
- * $Date: 2008-06-07 07:15:18 +0200 (sam 07 jun 2008) $
+ * $Date: 2009-02-17 05:31:44 +0000 (Tue, 17 Feb 2009) $
  */
 
 #include <ptlib.h>
@@ -729,6 +729,30 @@ void PThread::Win32AttachThreadInput()
 }
 
 
+PThread::PThread()
+  : autoDelete(false)
+  , originalStackSize(0)
+  , threadHandle(GetCurrentThread())
+  , threadId(GetCurrentThreadId())
+{
+  if (!PProcess::IsInitialised())
+    return;
+
+  autoDelete = true;
+  DuplicateHandle(GetCurrentProcess(), threadHandle, GetCurrentProcess(), &threadHandle, 0, 0, DUPLICATE_SAME_ACCESS);
+
+  PProcess & process = PProcess::Current();
+
+  process.activeThreadMutex.Wait();
+  process.activeThreads.SetAt(threadId, this);
+  process.activeThreadMutex.Signal();
+
+  process.deleteThreadMutex.Wait();
+  process.autoDeleteThreads.Append(this);
+  process.deleteThreadMutex.Signal();
+}
+
+
 PThread::PThread(PINDEX stackSize,
                  AutoDeleteFlag deletion,
                  Priority priorityLevel,
@@ -771,6 +795,80 @@ PThread::~PThread()
 }
 
 
+#if PTRACING
+static ULONGLONG ConvertTo64(const FILETIME & ft)
+{
+  ULARGE_INTEGER i;
+  i.HighPart = ft.dwHighDateTime;
+  i.LowPart = ft.dwLowDateTime;
+  return i.QuadPart;
+}
+
+static void OutputTime(ostream & str, ULONGLONG time)
+{
+  ULONGLONG upperbound = 10000;
+  ULONGLONG scale1 = 10;
+  ULONGLONG scale2 = 1;
+  int units = 0;
+  int decimals = 1;
+
+  while (time >= upperbound) {
+    if (--decimals == 0) {
+      if (units == 2) {
+        str << time/scale1 << 's';
+        return;
+      }
+
+      scale1 *= 1000;
+      decimals = 3;
+      ++units;
+    }
+    upperbound *= 10;
+    scale2 *= 10;
+  }
+
+  static const char * const UnitNames[] = { "us", "ms", "s" };
+  str << time/scale1
+      << '.' << setfill('0') << setw(decimals)
+      << (time%scale1)/scale2
+      << UnitNames[units];
+}
+
+static void OutputThreadTimes(const PThread & thread)
+{
+  if (!PTrace::CanTrace(3))
+    return;
+
+  FILETIME created_f, exit_f, kernel_f, user_f;
+  exit_f.dwHighDateTime = exit_f.dwLowDateTime = 0;
+  if (!GetThreadTimes(thread.GetHandle(), &created_f, &exit_f, &kernel_f, &user_f))
+    return;
+
+  ULONGLONG created = ConvertTo64(created_f);
+  ULONGLONG exit    = ConvertTo64(exit_f);
+  ULONGLONG kernel  = ConvertTo64(kernel_f);
+  ULONGLONG user    = ConvertTo64(user_f);
+
+  ostream & output = PTrace::Begin(3, __FILE__, __LINE__);
+  output << "PTLib\tThread ended: name=\"" << thread.GetThreadName() << "\", kernel=";
+  OutputTime(output, kernel);
+  output << ", user=";
+  OutputTime(output, user);
+  output << ", elapsed=";
+  OutputTime(output, exit-created);
+  if (exit > created) {
+    ULONGLONG percent = 1000*(kernel+user)/(exit-created);
+    if (percent > 0)
+      output << " (" << percent/10 << '.' << percent%10 << "%)";
+    else
+      output << " (<0.1%)";
+  }
+  output << PTrace::End;
+}
+#else
+#define OutputThreadTimes(t)
+#endif
+
 void PThread::CleanUp()
 {
   PProcess & process = PProcess::Current();
@@ -781,8 +879,10 @@ void PThread::CleanUp()
   if (!IsTerminated())
     Terminate();
 
-  if (threadHandle != NULL)
+  if (threadHandle != NULL) {
+    OutputThreadTimes(*this);
     CloseHandle(threadHandle);
+  }
 }
 
 
@@ -907,30 +1007,17 @@ void PThread::SetAutoDelete(AutoDeleteFlag deletion)
   autoDelete = deletion == AutoDeleteThread;
 }
 
-#if !defined(_WIN32_WCE) || (_WIN32_WCE < 300)
-#define PTHREAD_PRIORITY_LOWEST THREAD_PRIORITY_LOWEST
-#define PTHREAD_PRIORITY_BELOW_NORMAL THREAD_PRIORITY_BELOW_NORMAL
-#define PTHREAD_PRIORITY_NORMAL THREAD_PRIORITY_NORMAL
-#define PTHREAD_PRIORITY_ABOVE_NORMAL THREAD_PRIORITY_ABOVE_NORMAL
-#define PTHREAD_PRIORITY_HIGHEST THREAD_PRIORITY_HIGHEST
-#else
-#define PTHREAD_PRIORITY_LOWEST 243
-#define PTHREAD_PRIORITY_BELOW_NORMAL 245
-#define PTHREAD_PRIORITY_NORMAL 247
-#define PTHREAD_PRIORITY_ABOVE_NORMAL 249
-#define PTHREAD_PRIORITY_HIGHEST 251
-#endif
 
 void PThread::SetPriority(Priority priorityLevel)
 {
   PAssert(!IsTerminated(), "Operation on terminated thread");
 
   static int const priorities[NumPriorities] = {
-    PTHREAD_PRIORITY_LOWEST,
-    PTHREAD_PRIORITY_BELOW_NORMAL,
-    PTHREAD_PRIORITY_NORMAL,
-    PTHREAD_PRIORITY_ABOVE_NORMAL,
-    PTHREAD_PRIORITY_HIGHEST
+    THREAD_PRIORITY_LOWEST,
+    THREAD_PRIORITY_BELOW_NORMAL,
+    THREAD_PRIORITY_NORMAL,
+    THREAD_PRIORITY_ABOVE_NORMAL,
+    THREAD_PRIORITY_HIGHEST
   };
   SetThreadPriority(threadHandle, priorities[priorityLevel]);
 }
@@ -941,15 +1028,15 @@ PThread::Priority PThread::GetPriority() const
   PAssert(!IsTerminated(), "Operation on terminated thread");
 
   switch (GetThreadPriority(threadHandle)) {
-    case PTHREAD_PRIORITY_LOWEST :
+    case THREAD_PRIORITY_LOWEST :
       return LowestPriority;
-    case PTHREAD_PRIORITY_BELOW_NORMAL :
+    case THREAD_PRIORITY_BELOW_NORMAL :
       return LowPriority;
-    case PTHREAD_PRIORITY_NORMAL :
+    case THREAD_PRIORITY_NORMAL :
       return NormalPriority;
-    case PTHREAD_PRIORITY_ABOVE_NORMAL :
+    case THREAD_PRIORITY_ABOVE_NORMAL :
       return HighPriority;
-    case PTHREAD_PRIORITY_HIGHEST :
+    case THREAD_PRIORITY_HIGHEST :
       return HighestPriority;
   }
   PAssertAlways(POperatingSystemError);
@@ -963,49 +1050,37 @@ void PThread::Yield()
 }
 
 
-void PThread::InitialiseProcessThread()
-{
-  originalStackSize = 0;
-  autoDelete = PFalse;
-  threadHandle = GetCurrentThread();
-  threadId = GetCurrentThreadId();
-  ((PProcess *)this)->activeThreads.DisallowDeleteObjects();
-  ((PProcess *)this)->activeThreads.SetAt(threadId, this);
-}
-
-
-PThread * PThread::Current()
-{
-  PProcess & process = PProcess::Current();
-  process.activeThreadMutex.Wait();
-  PThread * thread = process.activeThreads.GetAt(GetCurrentThreadId());
-  process.activeThreadMutex.Signal();
-  return thread;
-}
-
-
 ///////////////////////////////////////////////////////////////////////////////
 // PProcess::TimerThread
 
 PProcess::HouseKeepingThread::HouseKeepingThread()
   : PThread(1000, NoAutoDeleteThread, NormalPriority, "PTLib Housekeeper")
+  , m_running(true)
 {
   Resume();
 }
 
 
+PProcess::HouseKeepingThread::~HouseKeepingThread()
+{
+  m_running = false;
+  m_breakBlock.Signal();
+  WaitForTermination(500);
+}
+
+
 void PProcess::HouseKeepingThread::Main()
 {
   PProcess & process = PProcess::Current();
 
-  for (;;) {
+  while (m_running) {
 
     // collect a list of thread handles to check, and clean up 
     // handles for threads that disappeared without telling us
     process.deleteThreadMutex.Wait();
     HANDLE handles[MAXIMUM_WAIT_OBJECTS];
     DWORD numHandles = 1;
-    handles[0] = breakBlock.GetHandle();
+    handles[0] = m_breakBlock.GetHandle();
     ThreadList::iterator thread = process.autoDeleteThreads.begin();
     while (thread != process.autoDeleteThreads.end()) {
       if (thread->IsTerminated())
@@ -1071,7 +1146,7 @@ void PProcess::SignalTimerChange()
   if (houseKeeper == NULL)
     houseKeeper = new HouseKeepingThread;
   else
-    houseKeeper->breakBlock.Signal();
+    houseKeeper->m_breakBlock.Signal();
   deleteThreadMutex.Signal();
 }
 
@@ -1109,8 +1184,7 @@ PProcess::~PProcess()
 #endif
 
 #if _DEBUG
-  extern void PWaitOnExitConsoleWindow();
-  PWaitOnExitConsoleWindow();
+  WaitOnExitConsoleWindow();
 #endif
 }
 
