@@ -26,9 +26,9 @@
  *
  * Contributor(s): ______________________________________.
  *
- * $Revision: 20725 $
- * $Author: ms30002000 $
- * $Date: 2008-08-22 20:21:16 +0200 (ven 22 aoû 2008) $
+ * $Revision: 22754 $
+ * $Author: rjongbloed $
+ * $Date: 2009-05-28 12:49:36 +0000 (Thu, 28 May 2009) $
  */
 
 #include <ptlib.h>
@@ -43,11 +43,10 @@
   #ifdef _MSC_VER
     #include <wsnwlink.h>
 
-    #if defined(P_WINSOCK2_LIBRARY)
-      #pragma comment(lib, P_WINSOCK2_LIBRARY)
-    #else
-      #pragma comment(lib, "wsock32.lib")
+    #ifndef P_WINSOCK2_LIBRARY
+      #define P_WINSOCK2_LIBRARY "ws2_32.lib"
     #endif
+    #pragma comment(lib, P_WINSOCK2_LIBRARY)
 
   #else
 
@@ -701,400 +700,5 @@ PWinQoS::PWinQoS(PQoS & pqos, struct sockaddr * to, char * inBuf, DWORD & bufLen
 
 #endif // P_QOS
 
-#ifndef _WIN32_WCE
-//////////////////////////////////////////////////////////////////////////////
-// PIPXSocket
 
-PIPXSocket::Address::Address()
-{
-  memset(this, 0, sizeof(*this));
-}
-
-
-PIPXSocket::Address::Address(const Address & addr)
-{
-  memcpy(this, &addr, sizeof(*this));
-}
-
-
-PIPXSocket::Address::Address(const PString & str)
-{
-  PINDEX colon = str.Find(':');
-  if (colon == P_MAX_INDEX)
-    colon = 0;
-  else {
-    DWORD netnum = 0;
-    for (PINDEX i = 0; i < colon; i++) {
-      int c = str[i];
-      if (isdigit(c))
-        netnum = (netnum << 4) + c - '0';
-      else if (isxdigit(c))
-        netnum = (netnum << 4) + toupper(c) - 'A' + 10;
-      else {
-        memset(this, 0, sizeof(*this));
-        return;
-      }
-    }
-    network.dw = ntohl(netnum);
-  }
-
-  memset(node, 0, sizeof(node));
-
-  int shift = 0;
-  PINDEX byte = 5;
-  PINDEX pos = str.GetLength();
-  while (--pos > colon) {
-    int c = str[pos];
-    if (c != '-') {
-      if (isdigit(c))
-        node[byte] |= (c - '0') << shift;
-      else if (isxdigit(c))
-        node[byte] |= (toupper(c) - 'A' + 10) << shift;
-      else {
-        memset(this, 0, sizeof(*this));
-        return;
-      }
-      if (shift == 0)
-        shift = 4;
-      else {
-        shift = 0;
-        byte--;
-      }
-    }
-  }
-}
-
-
-PIPXSocket::Address::Address(DWORD netNum, const char * nodeNum)
-{
-  network.dw = netNum;
-  memcpy(node, nodeNum, sizeof(node));
-}
-
-
-PIPXSocket::Address & PIPXSocket::Address::operator=(const Address & addr)
-{
-  memcpy(this, &addr, sizeof(*this));
-  return *this;
-}
-
-
-PIPXSocket::Address::operator PString() const
-{
-  return psprintf("%02X%02X%02X%02X:%02X%02X%02X%02X%02X%02X",
-                  network.b.b1, network.b.b2, network.b.b3, network.b.b4,
-                  node[0], node[1], node[2], node[3], node[4], node[5]);
-}
-
-
-PBoolean PIPXSocket::Address::IsValid() const
-{
-  static Address empty;
-  return memcmp(this, &empty, sizeof(empty)) != 0;
-}
-
-
-PIPXSocket::PIPXSocket(WORD newPort)
-{
-  SetPort(newPort);
-}
-
-
-PString PIPXSocket::GetName() const
-{
-  Address addr;
-  if (((PIPXSocket*)this)->GetPeerAddress(addr))
-    return addr;
-  else
-    return PString();
-}
-
-
-PBoolean PIPXSocket::OpenSocket()
-{
-  return ConvertOSError(os_handle = os_socket(AF_IPX, SOCK_DGRAM, NSPROTO_IPX));
-}
-
-
-const char * PIPXSocket::GetProtocolName() const
-{
-  return "ipx";
-}
-
-
-PBoolean PIPXSocket::SetPacketType(int type)
-{
-  return ConvertOSError(::setsockopt(os_handle,
-                           NSPROTO_IPX, IPX_PTYPE, (char *)&type, sizeof(type)));
-}
-
-
-int PIPXSocket::GetPacketType()
-{
-  int value;
-  int valSize = sizeof(value);
-  if (ConvertOSError(::getsockopt(os_handle,
-                                NSPROTO_IPX, IPX_PTYPE, (char *)&value, &valSize)))
-    return value;
-  return -1;
-}
-
-
-PString PIPXSocket::GetHostName(const Address & addr)
-{
-  return addr;
-}
-
-
-PBoolean PIPXSocket::GetHostAddress(Address &)
-{
-  return PFalse;
-}
-
-
-static void AssignAddress(sockaddr_ipx & sip, const PIPXSocket::Address & addr)
-{
-  memcpy(sip.sa_netnum, &addr.network, sizeof(sip.sa_netnum));
-  memcpy(sip.sa_nodenum, addr.node, sizeof(sip.sa_nodenum));
-}
-
-
-static void AssignAddress(PIPXSocket::Address & addr, const sockaddr_ipx & sip)
-{
-  memcpy(&addr.network, sip.sa_netnum, sizeof(addr.network));
-  memcpy(addr.node, sip.sa_nodenum, sizeof(addr.node));
-}
-
-
-#ifdef P_QOS
-PBoolean PIPXSocket::GetHostAddress(const PString & /*hostname*/, Address & /*addr*/)
-{
-  return PFalse;
-}
-#else
-PBoolean PIPXSocket::GetHostAddress(const PString & hostname, Address & addr)
-{
-  addr = hostname;
-  if (addr.IsValid())
-    return PTrue;
-
-  static GUID netware_file_server = SVCID_FILE_SERVER;
-  CSADDR_INFO addr_info[10];
-  DWORD buffer_length = sizeof(addr_info);
-  int num = GetAddressByName(NS_DEFAULT,
-                             &netware_file_server,
-                             (LPTSTR)(const char *)hostname,
-                             NULL,
-                             0,
-                             NULL,
-                             addr_info,
-                             &buffer_length,
-                             NULL,
-                             NULL
-                            );
-  if (num <= 0)
-    return PFalse;
-
-  AssignAddress(addr, *(sockaddr_ipx *)addr_info[0].RemoteAddr.lpSockaddr);
-  return PTrue;
-}
-#endif // P_QOS
-
-
-
-PBoolean PIPXSocket::GetLocalAddress(Address & addr)
-{
-  sockaddr_ipx sip;
-  int size = sizeof(sip);
-  if (!ConvertOSError(::getsockname(os_handle, (struct sockaddr *)&sip, &size)))
-    return PFalse;
-
-  AssignAddress(addr, sip);
-  return PTrue;
-}
-
-
-PBoolean PIPXSocket::GetLocalAddress(Address & addr, WORD & portNum)
-{
-  sockaddr_ipx sip;
-  int size = sizeof(sip);
-  if (!ConvertOSError(::getsockname(os_handle, (struct sockaddr *)&sip, &size)))
-    return PFalse;
-
-  AssignAddress(addr, sip);
-  portNum = Net2Host(sip.sa_socket);
-  return PTrue;
-}
-
-
-PBoolean PIPXSocket::GetPeerAddress(Address & addr)
-{
-  sockaddr_ipx sip;
-  int size = sizeof(sip);
-  if (!ConvertOSError(::getpeername(os_handle, (struct sockaddr *)&sip, &size)))
-    return PFalse;
-
-  AssignAddress(addr, sip);
-  return PTrue;
-}
-
-
-PBoolean PIPXSocket::GetPeerAddress(Address & addr, WORD & portNum)
-{
-  sockaddr_ipx sip;
-  int size = sizeof(sip);
-  if (!ConvertOSError(::getpeername(os_handle, (struct sockaddr *)&sip, &size)))
-    return PFalse;
-
-  AssignAddress(addr, sip);
-  portNum = Net2Host(sip.sa_socket);
-  return PTrue;
-}
-
-
-PBoolean PIPXSocket::Connect(const PString & host)
-{
-  Address addr;
-  if (GetHostAddress(host, addr))
-    return Connect(addr);
-  return PFalse;
-}
-
-
-PBoolean PIPXSocket::Connect(const Address & addr)
-{
-  // close the port if it is already open
-  if (IsOpen())
-    Close();
-
-  // make sure we have a port
-  PAssert(port != 0, "Cannot connect socket without setting port");
-
-  // attempt to create a socket
-  if (!OpenSocket())
-    return PFalse;
-
-  // attempt to lookup the host name
-  sockaddr_ipx sip;
-  memset(&sip, 0, sizeof(sip));
-  sip.sa_family = AF_IPX;
-  AssignAddress(sip, addr);
-  sip.sa_socket  = Host2Net(port);  // set the port
-  if (os_connect((struct sockaddr *)&sip, sizeof(sip)))
-    return PTrue;
-
-  os_close();
-  return PFalse;
-}
-
-
-PBoolean PIPXSocket::Listen(unsigned, WORD newPort, Reusability reuse)
-{
-  // make sure we have a port
-  if (newPort != 0)
-    port = newPort;
-
-  // close the port if it is already open
-  if (!IsOpen()) {
-    // attempt to create a socket
-    if (!OpenSocket())
-      return PFalse;
-  }
-
-  // attempt to listen
-  if (SetOption(SO_REUSEADDR, reuse == CanReuseAddress ? 1 : 0)) {
-    // attempt to listen
-    sockaddr_ipx sip;
-    memset(&sip, 0, sizeof(sip));
-    sip.sa_family = AF_IPX;
-    sip.sa_socket = Host2Net(port);       // set the port
-
-    if (ConvertOSError(::bind(os_handle, (struct sockaddr*)&sip, sizeof(sip)))) {
-      int size = sizeof(sip);
-      if (ConvertOSError(::getsockname(os_handle, (struct sockaddr*)&sip, &size))) {
-        port = Net2Host(sip.sa_socket);
-        return PTrue;
-      }
-    }
-  }
-
-  os_close();
-  return PFalse;
-}
-
-
-PBoolean PIPXSocket::ReadFrom(void * buf, PINDEX len, Address & addr, WORD & port)
-{
-  lastReadCount = 0;
-
-  sockaddr_ipx sip;
-  int addrLen = sizeof(sip);
-  if (os_recvfrom(buf, len, 0, (struct sockaddr *)&sip, &addrLen)) {
-    AssignAddress(addr, sip);
-    port = Net2Host(sip.sa_socket);
-  }
-
-  return lastReadCount > 0;
-}
-
-
-PBoolean PIPXSocket::WriteTo(const void * buf, PINDEX len, const Address & addr, WORD port)
-{
-  lastWriteCount = 0;
-
-  sockaddr_ipx sip;
-  sip.sa_family = AF_IPX;
-  AssignAddress(sip, addr);
-  sip.sa_socket = Host2Net(port);
-  return os_sendto(buf, len, 0, (struct sockaddr *)&sip, sizeof(sip));
-}
-
-
-//////////////////////////////////////////////////////////////////////////////
-// PSPXSocket
-
-PSPXSocket::PSPXSocket(WORD port)
-  : PIPXSocket(port)
-{
-}
-
-
-PBoolean PSPXSocket::OpenSocket()
-{
-  return ConvertOSError(os_handle = os_socket(AF_IPX, SOCK_STREAM, NSPROTO_SPX));
-}
-
-
-const char * PSPXSocket::GetProtocolName() const
-{
-  return "spx";
-}
-
-
-PBoolean PSPXSocket::Listen(unsigned queueSize, WORD newPort, Reusability reuse)
-{
-  if (PIPXSocket::Listen(queueSize, newPort, reuse) &&
-      ConvertOSError(::listen(os_handle, queueSize)))
-    return PTrue;
-
-  os_close();
-  return PFalse;
-}
-
-
-PBoolean PSPXSocket::Accept(PSocket & socket)
-{
-  PAssert(PIsDescendant(&socket, PIPXSocket), "Invalid listener socket");
-
-  sockaddr_ipx sip;
-  sip.sa_family = AF_IPX;
-  int size = sizeof(sip);
-  if (!os_accept(socket, (struct sockaddr *)&sip, &size))
-    return PFalse;
-
-  port = ((PIPXSocket &)socket).GetPort();
-  return PTrue;
-}
-
-#endif
 // End Of File ///////////////////////////////////////////////////////////////
