@@ -26,9 +26,9 @@
  *
  * Contributor(s): ______________________________________.
  *
- * $Revision: 20385 $
+ * $Revision: 22565 $
  * $Author: rjongbloed $
- * $Date: 2008-06-04 10:40:38 +0000 (Wed, 04 Jun 2008) $
+ * $Date: 2009-05-08 04:21:05 +0000 (Fri, 08 May 2009) $
  */
 
 #pragma implementation "channel.h"
@@ -104,8 +104,9 @@ PBoolean PChannel::PXSetIOBlock(PXBlockType type, const PTimeInterval & timeout)
         break;
 
       case PXReadBlock :
-        PAssert(px_readThread == NULL || px_lastBlockType != PXReadBlock,
-                "Attempt to do simultaneous reads from multiple threads.");
+        if (px_readThread != NULL && px_lastBlockType == PXReadBlock)
+          PAssertAlways(psprintf("Attempt to do simultaneous reads from multiple threads:"
+                                 " os_handle=%i, thread ID=0x%x", os_handle, px_readThread->GetThreadId()));
         // Fall into default case
 
       default :
