@@ -26,9 +26,9 @@
  *
  * Contributor(s): ______________________________________.
  *
- * $Revision: 21738 $
- * $Author: ykiryanov $
- * $Date: 2008-12-09 20:16:10 +0000 (Tue, 09 Dec 2008) $
+ * $Revision: 22729 $
+ * $Author: rjongbloed $
+ * $Date: 2009-05-27 01:21:12 +0000 (Wed, 27 May 2009) $
  */
 
 #define _CONFIG_CXX
@@ -49,10 +49,14 @@
 #define	EXTENSION		".ini"
 #define	ENVIRONMENT_CONFIG_STR	"/\~~environment~~\/"
 
-#ifdef P_MACOSX
+#if defined(P_MACOSX) || defined(P_SOLARIS)
 #define environ (NULL)
 #endif
 
+#if defined(__NetBSD__)
+extern char **environ;
+#endif
+
 //
 //  a single key/value pair
 //
